@@ -59,6 +59,8 @@ class RemoteBatchPEGASUS:
                 arguments,
                 isMultiCoreRequest,
                 siteInfo,
+                toolFilesInfo,
+                dockerImageInfo,
                 submissionScriptsInfo,
                 managerInfo,
                 x509SubmitProxy,
@@ -111,6 +113,8 @@ class RemoteBatchPEGASUS:
       self.computationMode          = managerInfo['computationMode']
       self.pegasusTemplates         = siteInfo['pegasusTemplates']
       self.submissionScriptCommands = siteInfo['submissionScriptCommands']
+      self.toolFilesInfo            = toolFilesInfo
+      self.dockerImageInfo          = dockerImageInfo
       self.submissionScriptsInfo    = submissionScriptsInfo
       self.x509SubmitProxy          = x509SubmitProxy
       self.sshIdentityPath          = sshIdentityPath
@@ -120,6 +124,11 @@ class RemoteBatchPEGASUS:
       self.nodeFileName = ""
       self.nodeList     = []
 
+      self.toolInputTemplateFileName  = ""
+      self.toolInputTemplate          = ""
+      self.toolOutputTemplateFileName = ""
+      self.toolOutputTemplate         = ""
+
 
    def __buildSerialFile(self):
       rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Batch','PEGASUS','serial')
@@ -407,6 +416,14 @@ class RemoteBatchPEGASUS:
       return(self.nodeFileName,self.nodeList)
 
 
+   def getBatchToolInputTemplate(self):
+      return(self.toolInputTemplateFileName,self.toolInputTemplate)
+
+
+   def getBatchToolOutputTemplate(self):
+      return(self.toolOutputTemplateFileName,self.toolOutputTemplate)
+
+
    def getUserDaxExecutables(self):
       daxExecutables = []
       if self.checkDaxPath:
