@@ -46,16 +46,21 @@ class VenueMechanismCore:
    def __init__(self,
                 timeHistoryLogs,
                 siteInfo,
+                toolFilesInfo,
+                dockerImageInfo,
                 submissionScriptsInfo,
                 managerInfo,
                 remoteMonitors,
                 isMultiCoreRequest,
                 nCpus,
                 nNodes,
-                ppn):
+                ppn,
+                event):
       self.logger                = logging.getLogger(__name__)
       self.timeHistoryLogs       = copy.copy(timeHistoryLogs)
       self.siteInfo              = copy.copy(siteInfo)
+      self.toolFilesInfo         = copy.copy(toolFilesInfo)
+      self.dockerImageInfo       = copy.copy(dockerImageInfo)
       self.submissionScriptsInfo = copy.copy(submissionScriptsInfo)
       self.managerInfo           = copy.copy(managerInfo)
       self.remoteJobMonitor      = remoteMonitors['job']
@@ -77,6 +82,7 @@ class VenueMechanismCore:
       self.nCpus              = nCpus
       self.nNodes             = nNodes
       self.ppn                = ppn
+      self.event              = event
 
       self.jobSubmitted  = False
       self.jobStatistics = {}
@@ -119,187 +125,6 @@ class VenueMechanismCore:
             self.logger.log(logging.ERROR,getLogMessage("Can't write to stderr: %s" % (message)))
 
 
-   def recordGridResourceUse(self):
-      reFiles = re.compile(self.timeHistoryLogs['jobGridResource'] + "_[0-9]+$")
-      dirFiles = os.listdir(self.instanceDirectory)
-      matchingFiles = filter(reFiles.search,dirFiles)
-      if len(matchingFiles) > 0:
-         matchingFiles.sort()
-         for matchingFile in matchingFiles:
-            if len(matchingFile) > len(self.timeHistoryLogs['jobGridResource']):
-               jobIndex = int(matchingFile[len(self.timeHistoryLogs['jobGridResource'])+1:])
-            else:
-               jobIndex = 1
-
-            if not jobIndex in self.jobStatistics:
-               self.jobStatistics[jobIndex] = JobStatistic(self.nCpus)
-
-            try:
-               gridResourcePath = os.path.join(self.instanceDirectory,matchingFile)
-               fpGridResource = open(gridResourcePath,'r')
-               try:
-                  gridResource = fpGridResource.readline().strip()
-               except (IOError,OSError):
-                  self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (gridResourcePath)))
-               else:
-                  gridType = gridResource.split()[0]
-                  if   gridType == 'gt2':
-                     gateKeeper = gridResource.split()[1].split('/')[0]
-                     jobManager = gridResource.split()[1].split('/')[1].split('-')[1].upper()
-                  elif gridType == 'gt4':
-                     gateKeeper = gridResource.split()[1]
-                     jobManager = gridResource.split()[2]
-                  elif gridType == 'gt5':
-                     gateKeeper = gridResource.split()[1].split('/')[0]
-                     jobManager = gridResource.split()[1].split('/')[1].split('-')[1].upper()
-
-                  self.jobStatistics[jobIndex]['venue']                  = gateKeeper
-                  self.jobStatistics[jobIndex]['jobSubmissionMechanism'] = self.venueMechanism + jobManager
-               finally:
-                  fpGridResource.close()
-            except (IOError,OSError):
-               self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridResourcePath)))
-
-            os.remove(os.path.join(self.instanceDirectory,matchingFile))
-      else:
-         message = self.timeHistoryLogs['jobGridResource'] + " not present in " + self.instanceDirectory
-         self.logger.log(logging.ERROR,getLogMessage(message))
-
-
-   def logGridHistories(self):
-
-      gridHistoryLogPath = self.timeHistoryLogs['hubGridJobHistoryLogPath']
-      try:
-         fpGridHistoryLog = open(gridHistoryLogPath,'a')
-      except (IOError,OSError):
-         fpGridHistoryLog = None
-         self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridHistoryLogPath)))
-
-      reFiles = re.compile(self.timeHistoryLogs['jobGridHistory'] + "_[0-9]+$")
-      dirFiles = os.listdir(self.instanceDirectory)
-      matchingFiles = filter(reFiles.search,dirFiles)
-      if len(matchingFiles) > 0:
-         matchingFiles.sort()
-         for matchingFile in matchingFiles:
-            if len(matchingFile) > len(self.timeHistoryLogs['jobGridHistory']):
-               jobIndex = int(matchingFile[len(self.timeHistoryLogs['jobGridHistory'])+1:])
-            else:
-               jobIndex = 1
-
-            if not jobIndex in self.jobStatistics:
-               self.jobStatistics[jobIndex] = JobStatistic(self.nCpus)
-
-            gridHistoryPath = os.path.join(self.instanceDirectory,matchingFile)
-            if fpGridHistoryLog:
-               try:
-                  fpGridHistory = open(gridHistoryPath,'r')
-                  try:
-                     gridHistory = fpGridHistory.readline()
-                  except (IOError,OSError):
-                     self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (gridHistoryPath)))
-                  else:
-                     try:
-                        fpGridHistoryLog.write("%s_%s\t%d\t%s\t%s\n" % (self.localJobId,self.instanceId,jobIndex, \
-                                                                        gridHistory.strip(),self.enteredCommand))
-                     except (IOError,OSError):
-                        self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (gridHistoryLogPath)))
-                  finally:
-                     fpGridHistory.close()
-               except (IOError,OSError):
-                  self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridHistoryPath)))
-            os.remove(gridHistoryPath)
-
-      reFiles = re.compile(self.timeHistoryLogs['jobGridHistory'] + "_[0-9]+_$")
-      dirFiles = os.listdir(self.instanceDirectory)
-      matchingFiles = filter(reFiles.search,dirFiles)
-      if len(matchingFiles) > 0:
-         matchingFiles.sort()
-         for matchingFile in matchingFiles:
-            if len(matchingFile) > len(self.timeHistoryLogs['jobGridHistory']):
-               jobIndex = int(matchingFile[len(self.timeHistoryLogs['jobGridHistory'])+1:-1])
-            else:
-               jobIndex = 1
-
-            if not jobIndex in self.jobStatistics:
-               self.jobStatistics[jobIndex] = JobStatistic(self.nCpus)
-
-            gridHistoryPath = os.path.join(self.instanceDirectory,matchingFile)
-            if fpGridHistoryLog:
-               try:
-                  fpGridHistory = open(gridHistoryPath,'r')
-                  try:
-                     jobInProgressSite,jobInProgressSetupCompleted = fpGridHistory.readline().rstrip().split()
-                  except (IOError,OSError):
-                     self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (gridHistoryPath)))
-                  else:
-                     jobInProgressCompleted = int(time.mktime(datetime.datetime.utcnow().timetuple()))
-                     jobInProgressExitStatus = -3
-                     try:
-                        fpGridHistoryLog.write("%s_%s\t%d\t%s\t%s\t%d\t%d\t%s\n" % (self.localJobId,self.instanceId,jobIndex, \
-                                                                                    jobInProgressSite, \
-                                                                                    jobInProgressSetupCompleted, \
-                                                                                    jobInProgressCompleted,
-                                                                                    jobInProgressExitStatus, \
-                                                                                    self.enteredCommand))
-                     except (IOError,OSError):
-                        self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (gridHistoryLogPath)))
-                  finally:
-                     fpGridHistory.close()
-               except (IOError,OSError):
-                  self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridHistoryPath)))
-            os.remove(gridHistoryPath)
-
-      if fpGridHistoryLog:
-         fpGridHistoryLog.close()
-
-
-   def logGridJobId(self):
-      reFiles = re.compile(self.timeHistoryLogs['jobGridJobId'] + "_[0-9]+$")
-      dirFiles = os.listdir(self.instanceDirectory)
-      matchingFiles = filter(reFiles.search,dirFiles)
-      if len(matchingFiles) > 0:
-         gridJobIdLogPath = self.timeHistoryLogs['hubGridJobIdLogPath']
-         try:
-            fpGridJobIdLog = open(gridJobIdLogPath,'a')
-         except (IOError,OSError):
-            fpGridJobIdLog = None
-            self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridJobIdLogPath)))
-
-         matchingFiles.sort()
-         for matchingFile in matchingFiles:
-            if len(matchingFile) > len(self.timeHistoryLogs['jobGridJobId']):
-               jobIndex = int(matchingFile[len(self.timeHistoryLogs['jobGridJobId'])+1:])
-            else:
-               jobIndex = 1
-
-            if not jobIndex in self.jobStatistics:
-               self.jobStatistics[jobIndex] = JobStatistic(self.nCpus)
-
-            gridJobIdPath = os.path.join(self.instanceDirectory,matchingFile)
-            if fpGridJobIdLog:
-               try:
-                  fpGridJobId = open(gridJobIdPath,'r')
-                  try:
-                     gridJobId = fpGridJobId.readline()
-                  except (IOError,OSError):
-                     self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (gridJobIdPath)))
-                  else:
-                     try:
-                        fpGridJobIdLog.write("%s_%s %s\n" % (self.localJobId.lstrip('0'),self.instanceId,gridJobId.strip()))
-                     except (IOError,OSError):
-                        self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (gridJobIdLogPath)))
-                  finally:
-                     fpGridJobId.close()
-               except (IOError,OSError):
-                  self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (gridJobIdPath)))
-            os.remove(gridJobIdPath)
-         if fpGridJobIdLog:
-            fpGridJobIdLog.close()
-      else:
-         message = self.timeHistoryLogs['jobGridJobId'] + " not present in " + self.instanceDirectory
-         self.logger.log(logging.ERROR,getLogMessage(message))
-
-
    def executeCommand(self,
                       command,
                       streamOutput=False):
@@ -480,6 +305,19 @@ class VenueMechanismCore:
          if self.jobSubmitted:
             self.logger.log(logging.ERROR,getLogMessage(timeFileBasename + " not present in " + self.instanceDirectory))
 
+# files of this form are generated by non parametric dax execution
+      reFiles = re.compile(timeFileBasename + "_[0-9]+$")
+      dirFiles = os.listdir(self.instanceDirectory)
+      matchingFiles = filter(reFiles.search,dirFiles)
+      if len(matchingFiles) > 0:
+         maximumJobIndex = max(self.jobStatistics.keys())
+         jobIndex = maximumJobIndex
+         for matchingFile in matchingFiles:
+            jobIndex += 1
+            self.jobStatistics[jobIndex] = JobStatistic(1)
+            timerPath = os.path.join(self.instanceDirectory,matchingFile)
+            self.jobStatistics[jobIndex].recordTimer(timerPath)
+
 
    def recordJobStatistics(self):
       self.recordJobStatisticTimer(self.timeHistoryLogs['timeResults'])
