@@ -78,12 +78,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                 transferExecutable,
                 executable,
                 appsAccessInfo,
+                event,
                 stdinput,
                 arguments,
                 useEnvironment,
                 environment,
                 isMultiCoreRequest,
                 siteInfo,
+                toolFilesInfo,
+                dockerImageInfo,
                 submissionScriptsInfo,
                 managerInfo,
                 nCpus,
@@ -97,8 +100,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                 useSetup,
                 pegasusVersion,
                 pegasusHome):
-      VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,submissionScriptsInfo,managerInfo,
-                                       remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn)
+      VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
+                                       remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,event)
 
       self.logger                           = logging.getLogger(__name__)
       self.jobOutput                        = JobOutput()
@@ -181,6 +184,8 @@ class VenueMechanismSsh(VenueMechanismCore):
       self.appScriptPath                    = ""
       self.batchScriptPath                  = ""
       self.nodeFilePath                     = ""
+      self.toolInputTemplateFilePath        = ""
+      self.toolOutputTemplateFilePath       = ""
       self.remoteJobIdNumber                = ""
       self.sshBaseCommand                   = ""
       self.sshIdentityPath                  = ""
@@ -284,12 +289,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.runName,self.localJobId,self.instanceId,appScriptName,self.environment,
                                               self.transferExecutable,
                                               self.executable,self.arguments,self.stdinput,
-                                              self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                              self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                              self.submissionScriptsInfo,
                                               self.managerInfo,self.nNodes,self.ppn,
                                               self.wallTime,self.quotaLimit,
                                               self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'SGE':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -303,12 +311,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.runName,self.localJobId,self.instanceId,appScriptName,self.environment,
                                               self.transferExecutable,
                                               self.executable,self.arguments,self.stdinput,
-                                              self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                              self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                              self.submissionScriptsInfo,
                                               self.managerInfo,self.nNodes,self.ppn,
                                               self.wallTime,self.quotaLimit,
                                               self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'LSF':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -322,12 +333,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.runName,self.localJobId,self.instanceId,appScriptName,self.environment,
                                               self.transferExecutable,
                                               self.executable,self.arguments,self.stdinput,
-                                              self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                              self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                              self.submissionScriptsInfo,
                                               self.managerInfo,self.nNodes,self.ppn,
                                               self.wallTime,self.quotaLimit,
                                               self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'LL':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -341,12 +355,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                              self.runName,self.localJobId,self.instanceId,appScriptName,self.environment,
                                              self.transferExecutable,
                                              self.executable,self.arguments,self.stdinput,
-                                             self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                             self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                             self.submissionScriptsInfo,
                                              self.managerInfo,self.nNodes,self.ppn,
                                              self.wallTime,self.quotaLimit,
                                              self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'SLURM':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -360,12 +377,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                 self.runName,self.localJobId,self.instanceId,appScriptName,self.environment,
                                                 self.transferExecutable,
                                                 self.executable,self.arguments,self.stdinput,
-                                                self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                self.submissionScriptsInfo,
                                                 self.managerInfo,self.nNodes,self.ppn,
                                                 self.wallTime,self.quotaLimit,
                                                 self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'CONDOR':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -378,10 +398,13 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.remoteBatch = RemoteBatchCONDOR(self.hubUserName,self.hubUserId,self.submitterClass,
                                                  self.runName,self.localJobId,self.instanceId,self.instanceDirectory,
                                                  appScriptName,self.environment,
-                                                 self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                 self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                 self.submissionScriptsInfo,
                                                  self.managerInfo,self.wallTime)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'BOINC':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -394,10 +417,13 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.remoteBatch = RemoteBatchBOINC(self.hubUserName,self.hubUserId,self.submitterClass,
                                                 self.runName,self.localJobId,self.instanceId,self.instanceDirectory,
                                                 appScriptName,self.environment,
-                                                self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                self.submissionScriptsInfo,
                                                 self.managerInfo,self.wallTime)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'FACTORY':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -410,10 +436,13 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.remoteBatch = RemoteBatchFACTORY(self.hubUserName,self.hubUserId,self.submitterClass,
                                                   self.runName,self.localJobId,self.instanceId,self.instanceDirectory,
                                                   appScriptName,self.environment,
-                                                  self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                  self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                  self.submissionScriptsInfo,
                                                   self.managerInfo,self.x509SubmitProxy,self.wallTime)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'PEGASUS':
             if self.isParametric:
                if self.instanceId != "0":
@@ -425,11 +454,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                               self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
                                                               self.managerInfo,self.timeHistoryLogs)
                   appScriptName,appScript,appScriptExecutable = self.remoteAppScript.buildAppScript()
-                  batchLogName    = ""
-                  batchScriptName = ""
-                  batchScript     = ""
-                  nodeFileName    = ""
-                  nodeList        = []
+                  batchLogName               = ""
+                  batchScriptName            = ""
+                  batchScript                = ""
+                  nodeFileName               = ""
+                  nodeList                   = []
+                  toolInputTemplateFileName  = ""
+                  toolInputTemplate          = ""
+                  toolOutputTemplateFileName = ""
+                  toolOutputTemplate         = ""
                else:
                   appScriptName = ""
                   appScript     = ""
@@ -442,9 +475,13 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                            self.gridsite,self.pegasusSiteInfo,self.wallTime,
                                                            self.siteInfo,self.submissionScriptsInfo,self.timeHistoryLogs)
                   batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildWorkflowScript()
-                  batchLogName = ""
-                  nodeFileName = ""
-                  nodeList     = []
+                  batchLogName               = ""
+                  nodeFileName               = ""
+                  nodeList                   = []
+                  toolInputTemplateFileName  = ""
+                  toolInputTemplate          = ""
+                  toolOutputTemplateFileName = ""
+                  toolOutputTemplate         = ""
             else:
                self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                            self.runName,self.localJobId,self.instanceId,False,
@@ -461,12 +498,15 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                      self.useSetup,self.pegasusVersion,self.pegasusHome,
                                                      appScriptName,
                                                      self.executable,self.arguments,self.isMultiCoreRequest,
-                                                     self.siteInfo,self.submissionScriptsInfo,self.managerInfo,
+                                                     self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                     self.submissionScriptsInfo,self.managerInfo,
                                                      self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.pegasusSiteInfo,
                                                      self.wallTime,self.timeHistoryLogs)
                batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-               nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
-               userDaxExecutables = self.remoteBatch.getUserDaxExecutables()
+               nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+               toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+               toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
+               userDaxExecutables                                             = self.remoteBatch.getUserDaxExecutables()
                for userDaxExecutable in userDaxExecutables:
                   submissionAllowed,executableClassification = self.appsAccessInfo.isSubmissionAllowed(userDaxExecutable)
                   if not submissionAllowed:
@@ -495,11 +535,14 @@ class VenueMechanismSsh(VenueMechanismCore):
             appScriptName,appScript,appScriptExecutable = self.remoteAppScript.buildAppScript()
             self.remoteBatch = RemoteInstantSCRIPT(self.hubUserName,self.hubUserId,self.submitterClass,
                                                    self.runName,self.localJobId,self.instanceId,self.workingDirectory,appScriptName,
-                                                   self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                   self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                   self.submissionScriptsInfo,
                                                    self.managerInfo,self.nNodes,self.ppn,
                                                    self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
          elif self.remoteBatchSystem == 'BGSCRIPT':
             self.remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,self.submitterClass,
                                                         self.runName,self.localJobId,self.instanceId,False,
@@ -511,26 +554,35 @@ class VenueMechanismSsh(VenueMechanismCore):
             appScriptName,appScript,appScriptExecutable = self.remoteAppScript.buildAppScript()
             self.remoteBatch = RemoteInstantSCRIPT(self.hubUserName,self.hubUserId,self.submitterClass,
                                                    self.runName,self.localJobId,self.instanceId,self.workingDirectory,appScriptName,
-                                                   self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
+                                                   self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
+                                                   self.submissionScriptsInfo,
                                                    self.managerInfo,self.nNodes,self.ppn,
                                                    self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
-            nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
+            nodeFileName,nodeList                                          = self.remoteBatch.getBatchNodeList()
+            toolInputTemplateFileName,toolInputTemplate                    = self.remoteBatch.getBatchToolInputTemplate()
+            toolOutputTemplateFileName,toolOutputTemplate                  = self.remoteBatch.getBatchToolOutputTemplate()
 
          if batchLogName != "":
-            self.batchLogPath    = os.path.join(self.instanceDirectory,batchLogName)
+            self.batchLogPath               = os.path.join(self.instanceDirectory,batchLogName)
          if appScriptName != "":
-            self.appScriptPath   = os.path.join(self.instanceDirectory,appScriptName)
+            self.appScriptPath              = os.path.join(self.instanceDirectory,appScriptName)
          if batchScriptName != "":
-            self.batchScriptPath = os.path.join(self.instanceDirectory,batchScriptName)
+            self.batchScriptPath            = os.path.join(self.instanceDirectory,batchScriptName)
          if nodeFileName != "":
-            self.nodeFilePath    = os.path.join(self.instanceDirectory,nodeFileName)
+            self.nodeFilePath               = os.path.join(self.instanceDirectory,nodeFileName)
+         if toolInputTemplateFileName != "":
+            self.toolInputTemplateFilePath  = os.path.join(self.instanceDirectory,toolInputTemplateFileName)
+         if toolOutputTemplateFileName != "":
+            self.toolOutputTemplateFilePath = os.path.join(self.instanceDirectory,toolOutputTemplateFileName)
 
          jobSubmissionMechanism = self.venueMechanism + self.remoteBatchSystem
          self.jobIndex = int(self.instanceId)
          if not self.jobIndex in self.jobStatistics:
             self.jobStatistics[self.jobIndex] = JobStatistic(self.nCpus)
          self.jobStatistics[self.jobIndex]['jobSubmissionMechanism'] = jobSubmissionMechanism
+         if self.event:
+            self.jobStatistics[self.jobIndex]['event'] = self.event
 
          if batchScript != "":
             try:
@@ -586,6 +638,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                   self._writeToStderr("%s could not be written\n" % (self.nodeFilePath))
                   self.jobStatistics[0]['exitCode'] = 1
                   exitCode = 1
+               else:
+                  scriptFiles.append(self.nodeFilePath)
                finally:
                   fpNodes.close()
             except (IOError,OSError):
@@ -593,6 +647,42 @@ class VenueMechanismSsh(VenueMechanismCore):
                self._writeToStderr("%s could not be opened\n" % (self.nodeFilePath))
                self.jobStatistics[0]['exitCode'] = 1
                exitCode = 1
+
+         if toolInputTemplate != "":
+            try:
+               fpToolInputTemplate = open(self.toolInputTemplateFilePath,'w')
+               try:
+                  fpToolInputTemplate.write(toolInputTemplate)
+               except (IOError,OSError):
+                  self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (self.toolInputTemplateFilePath)))
+                  self._writeToStderr("%s could not be written\n" % (self.toolInputTemplateFilePath))
+                  self.jobStatistics[0]['exitCode'] = 1
+                  exitCode = 1
+               finally:
+                  fpToolInputTemplate.close()
+            except (IOError,OSError):
+               self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (self.toolInputTemplateFilePath)))
+               self._writeToStderr("%s could not be opened\n" % (self.toolInputTemplateFilePath))
+               self.jobStatistics[0]['exitCode'] = 1
+               exitCode = 1
+
+         if toolOutputTemplate != "":
+            try:
+               fpToolOutputTemplate = open(self.toolOutputTemplateFilePath,'w')
+               try:
+                  fpToolOutputTemplate.write(toolOutputTemplate)
+               except (IOError,OSError):
+                  self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (self.toolOutputTemplateFilePath)))
+                  self._writeToStderr("%s could not be written\n" % (self.toolOutputTemplateFilePath))
+                  self.jobStatistics[0]['exitCode'] = 1
+                  exitCode = 1
+               finally:
+                  fpToolOutputTemplate.close()
+            except (IOError,OSError):
+               self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (self.toolOutputTemplateFilePath)))
+               self._writeToStderr("%s could not be opened\n" % (self.toolOutputTemplateFilePath))
+               self.jobStatistics[0]['exitCode'] = 1
+               exitCode = 1
       else:
          exitCode = 1
 
@@ -606,11 +696,6 @@ class VenueMechanismSsh(VenueMechanismCore):
       self.filesSent = True
 
       exitStatus = 0
-
-#     if self.remoteBatchQueue != "":
-#        self.jobStatistics[self.jobIndex]['venue'] = self.remoteBatchQueue + '@' + self.venue
-#     else:
-#        self.jobStatistics[self.jobIndex]['venue'] = self.venue
       self.jobStatistics[self.jobIndex]['venue'] = self.venue
 
       if   not self.sharedUserSpace and self.stageFiles:
@@ -618,7 +703,7 @@ class VenueMechanismSsh(VenueMechanismCore):
          remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
 
          if self.sshBaseCommand != "":
-            stageInTarPath = os.path.join(self.instanceDirectory,self.stageInTarFile)
+            stageInTarPath = os.path.join(self.instanceDirectory,self.stageInTarFile).replace(' ','\ ')
             command = "cat " + stageInTarPath + " | " + self.sshBaseCommand + \
                                                   " \"" + self.receiveInput + " " + \
                                                      remoteWorkingDirectory + " " + \
@@ -967,7 +1052,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             command = self.sshBaseCommand + " \"" + self.transmitResults + " " + \
                                                   remoteWorkingDirectory + " " + \
                                                          stageOutTarFile + "\"" + \
-                                            " | tar xzmf - --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
+                                            " | tar xzmf - --ignore-case --exclude '*hub-proxy.*' -C " + \
+                                                  self.instanceDirectory.replace(' ','\ ')
             self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
             self.logger.log(logging.INFO,getLogMessage(stdOutput))
@@ -1017,52 +1103,49 @@ class VenueMechanismSsh(VenueMechanismCore):
             if os.path.isfile(stageOutTarFile):
                if stageOutTarFile.endswith('.gz'):
                   command = "tar xzmf " + stageOutTarFile + \
-                                      " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
+                                      " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ','\ ')
                else:
                   command = "tar xmf " + stageOutTarFile + \
-                                     " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
+                                     " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ','\ ')
                self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeCommand(command)
                if exitStatus == 0:
                   os.remove(stageOutTarFile)
                else:
-                  self.logger.log(logging.ERROR,getLogMessage(stdOutput))
+                  self.jobStatistics[self.jobIndex]['exitCode'] = 12
+                  if stdOutput != "":
+                     if self.instanceId != "0":
+                        stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+                     else:
+                        stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
+                     try:
+                        fpStd = open(stdFile,'a')
+                        try:
+                           fpStd.write(stdOutput)
+                        except (IOError,OSError):
+                           self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (stdFile)))
+                        finally:
+                           fpStd.close()
+                     except (IOError,OSError):
+                        self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stdFile)))
+
+                  if stdError != "":
+                     if self.instanceId != "0":
+                        stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+                     else:
+                        stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
+                     try:
+                        fpStd = open(stdFile,'a')
+                        try:
+                           fpStd.write(stdError)
+                        except (IOError,OSError):
+                           self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (stdFile)))
+                        finally:
+                           fpStd.close()
+                     except (IOError,OSError):
+                        self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stdFile)))
                break
 
-         if exitStatus:
-            self.jobStatistics[self.jobIndex]['exitCode'] = 12
-#           if stdOutput != "":
-#              if self.instanceId != "0":
-#                 stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
-#              else:
-#                 stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
-#              try:
-#                 fpStd = open(stdFile,'a')
-#                 try:
-#                    fpStd.write(stdOutput)
-#                 except (IOError,OSError):
-#                    self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (stdFile)))
-#                 finally:
-#                    fpStd.close()
-#              except (IOError,OSError):
-#                 self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stdFile)))
-
-            if stdError != "":
-               if self.instanceId != "0":
-                  stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
-               else:
-                  stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
-               try:
-                  fpStd = open(stdFile,'a')
-                  try:
-                     fpStd.write(stdError)
-                  except (IOError,OSError):
-                     self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (stdFile)))
-                  finally:
-                     fpStd.close()
-               except (IOError,OSError):
-                  self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stdFile)))
-
       if not exitStatus:
          self.filesRetrieved = True
 
@@ -1145,6 +1228,12 @@ class VenueMechanismSsh(VenueMechanismCore):
          if self.nodeFilePath:
             if os.path.isfile(self.nodeFilePath):
                os.remove(self.nodeFilePath)
+         if self.toolInputTemplateFilePath:
+            if os.path.isfile(self.toolInputTemplateFilePath):
+               os.remove(self.toolInputTemplateFilePath)
+         if self.toolOutputTemplateFilePath:
+            if os.path.isfile(self.toolOutputTemplateFilePath):
+               os.remove(self.toolOutputTemplateFilePath)
          if self.batchLogPath:
             if os.path.isfile(self.batchLogPath):
                os.remove(self.batchLogPath)
